# Svet
No gil Python package manager.

### Project status
At this stage this is just an experiment to see if I can write a package manager running
on no gil Python, that is considerably more performant than existing solutions.

This may turn into a production release in the future...

